Skip to contents

operates on a singular title level splits it, checks that if both/all sub titles are valid titles, then returns a boolean whether and was used as a title separator later lapply-ed for standardize_and usage

as opposed to and, its default is true

Usage

amp_helper(x)

Arguments

x

A character vector of titles.