standardize versions of 'coordinator'
fix_coordinator.Rdcondenses coordinator abbreviations to a standardized form note: instead of standardizing "CO" at the end of a title to coordinator, it is instead mapped to "COMMITTEE"
fix_coordinator.Rdcondenses coordinator abbreviations to a standardized form note: instead of standardizing "CO" at the end of a title to coordinator, it is instead mapped to "COMMITTEE"