fixes spelling wrapper function
fix_spelling.Rdapply custom dictionary of common abbreviations and misspellings to fix spelling of titles operates on the title level instead of data frame and is used also in step 3 as well
fix_spelling.Rdapply custom dictionary of common abbreviations and misspellings to fix spelling of titles operates on the title level instead of data frame and is used also in step 3 as well