Skip to contents

remove all quantifiers and qualifiers we create flags for all of the qualifiers too the qualifiers include: schedule o, at large, as needed, ex officio, co, ordinal numbers, and role statuses (former, future, current, and interim)

roughly 5 minutes for 100,000 titles

Usage

gen_status_codes(comp.data, title = "TitleTxt5", gs_status_codes = NULL)

Arguments

comp.data

A Part VII compensation data frame.

title

Name of the title column to operate on.

gs_status_codes

Optional status-code crosswalk data frame; if NULL, loaded from the bundled snapshot.