Skip to contents

TODO not written yet, but we will generate the taxonomy using the dynamic google sheets no longer manipulating the titles

Usage

gen_taxonomy(comp.data)

Arguments

comp.data

A Part VII compensation data frame.