Skip to contents

generate all the titles that contain a given word and output a dataframe including the original raw title and its cleaned version this function works for individual words as well as word lists

Usage

get_title_dump(comp.table, target.word)

Arguments

comp.table

A Part VII compensation data frame.

target.word

A word, or vector of words, to search for within titles.