retrieve all status variants for a unique status code
get_variants.RdSearch for variants of a status code (stored in google sheets), and combine them all into a single regex search string separated by OR.
get_variants.RdSearch for variants of a status code (stored in google sheets), and combine them all into a single regex search string separated by OR.