Skip to contents

cleans the dates by first identifying date, setting a flag if it finds one, then removing the date if it is present

Usage

remove_dates(df, title = "F9_07_COMP_DTK_TITLE")

Arguments

df

A Part VII compensation data frame.

title

Name of the title column to operate on.