Skip to contents

creates a flag for a split, and then builds out a new data frame (combining it back together) later –> should run much faster

runtime compared to old code is about several magnitudes faster than before

Usage

split_titles(df, title = "TitleTxt3")

Arguments

df

A Part VII compensation data frame.

title

Name of the title column to operate on.