Skip to contents

Maps multiple variants of a title onto the standard form that is defined in the Google sheet: Title standardization crosswalk

Usage

standardize_titles(
  comp.data,
  title = "TitleTxt6",
  hours = "TOT.HOURS",
  pay = "TOT.COMP",
  officer = "F9_07_COMP_DTK_POS_OFF_X",
  gs_title_xwalk = NULL
)

Arguments

comp.data

A Part VII compensation data frame.

title

Name of the title column to operate on.

hours

Name of the weekly-hours column.

pay

Name of the total-compensation column.

officer

Name of the officer-flag column.

gs_title_xwalk

Optional title-standardization crosswalk; if NULL, loaded from the bundled snapshot.