Skip to contents

detects whether to is part of a date or not if it is, replace with "UNTIL", if not, leave be

Note: we have already removed dates by this point so we cannot look for numbers as a means of detecting date

alternate way of standardize to is to check the date flag: if we detected a date, then likely the "to" should be an until

Usage

standardize_to(TitleTxt)

Arguments

TitleTxt

A character vector of titles.