add a boolean status flag to the compensation dataframe
add_status_flag.RdSearch for variants of a status code and add a boolean flag to the data frame, 1 if any status variant is present in the tite, 0 otherwise.
Arguments
- df
A compensation dataframe
- title
Which version of the title string to use (defaults to "TitleTxt6")
- s.code
Any of the unique status.qualifier strings from df.status (e.g. "FORMER")
- variants
Regex alternation of status-code variants (from
get_variants()).