create a status code flag and KEEP the standardized version of the string
flag_and_keep.RdSearch for variants of a status code (stored in google sheets), create a boolean flag in the dataset, and replace the status variant in the title with the standardized version. The flag variable is named SCODE.X (e.g. REGIONAL.X).