get title dump function
get_title_dump.Rdgenerate all the titles that contain a given word and output a dataframe including the original raw title and its cleaned version this function works for individual words as well as word lists
get_title_dump.Rdgenerate all the titles that contain a given word and output a dataframe including the original raw title and its cleaned version this function works for individual words as well as word lists