remove/clean dates wrapper function, takes in a data frame
remove_dates.Rdcleans the dates by first identifying date, setting a flag if it finds one, then removing the date if it is present
remove_dates.Rdcleans the dates by first identifying date, setting a flag if it finds one, then removing the date if it is present