remove a status qualifier from the title
remove_status.RdSearch for variants of a status code and remove them. If the status code is the entire title (e.g. 'ex officio') it is replaced with the standardized version of the status code.
Arguments
- x
Vector of titles
- variants
Regex alternation of status-code variants (from
get_variants()).