split titles wrapper function
split_titles.Rdcreates a flag for a split, and then builds out a new data frame (combining it back together) later –> should run much faster
runtime compared to old code is about several magnitudes faster than before
split_titles.Rdcreates a flag for a split, and then builds out a new data frame (combining it back together) later –> should run much faster
runtime compared to old code is about several magnitudes faster than before