replace status variant with the standardized version
standardize_status.RdSearch for variants of a status code and replace the variant with the standardized version of the status code.
Arguments
- x
Vector of titles
- s.code
Any of the unique status.qualifier strings from df.status
- variants
Regex alternation of status-code variants (from
get_variants()).